@@ -112,16 +112,7 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2014-11-03
-## Updates:
-## 2014-11-09 Various fixes for memos, indexing into char arrays, etc
-## 2014-11-11 Style fixes & comments added
-## 2014-11-15 Provide empty variables in case recs = 0 (exploring)
-## 2014-11-17 dBase IV
-## 2014-12-24 Fix wrong indexing of found logical values in output array
-## 2014-12-29 Properly implement selecting data columns on cellstr headers
-## 2015-01-01 Better version and memo presence detection
-##     ''     Move reading memo file down to when it's sure data will be read
-##
+
 ## References:
 ## http://ulisse.elettra.trieste.it/services/doc/dbase/DBFstruct.htm
 ## http://www.dbf2002.com/dbf-file-format.html
@@ -341,6 +332,7 @@ function [data, datinfo] = dbfread (fname, recs=[], cols=[], rd_erased='')
             dlf = cellstr (fld);
             ## Catch empty date fields. Put ridiculous value in
             dlf(find (strcmp (cellstr (fld), "00000000"))) = "99991231";
+            dlf(find (cellfun ("isempty", dlf))) = "99991231";
             dlf = datenum (dlf, "yyyymmdd");
             ## Reset temp values for empty dates
             dlf (dlf >= 3652425) = 0;
